% This script generates the persistent intervals for coauthorship networks
% in a research journal. The publications in 11 journals have been cleaned
% and stored in the excel files in this folder. We consider all
% publications but only construct sets of authors no more than three. The
% number of publications for a set of authors is counted and stored.
%
% Since it needs to be called manually for each excel file, we attach the
% stored persistence for 5Y_persistence_intervals.mat (5 year data for 11
% journals in math and engieering) and ASW_persistence_intervals.mat (IEEE
% TAC, TSP, and TWC), and can be found in persistence_codes on
% weiyuhuang.net
%
% The readers interested in generating persistent intervals themselves can
% use this file to generate persistence intervals. Need to load JavaPlex
% first
%
% All publication records are downloaded with University access (University
% of Pennsylvania access) from Engineering village. Further usage of such
% data needs to be disclosed by noting the source: ?Engineering Village:
% The place to find answers to engineering ques-tions.? (2014). [Online].
% Available: http://www.engineeringvillage.com/search/quick.url
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

filename = 'TSP-2013';

[num,txt] = xlsread([filename,'.xlsx']);

[ d1, d2, d3, d1_unNor, d2_unNor, d3_unNor, idx, num_of_authors, num_of_pub ] = constructCN_main_123( txt );

%%%%%%%%%%%%%%%%%%%%%%%%
%%% T I M E S  1 0 0 %%%
%%%%%%%%%%%%%%%%%%%%%%%%

d1 = d1*100; d2(:,3) = d2(:,3)*100 + 1; d3(:,4) = d3(:,4)*100 + 2; %d4(:,5) = d4(:,5)*100;

% construct complex

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% C O N S T R U C T   C O M P L E X %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear stream m_int
stream = api.Plex4.createExplicitSimplexStream();

% denote sizes
d2_size = size(d2);
d3_size = size(d3);

% nodes
for i = 1:num_of_authors
    stream.addVertex(i, d1(i));
end

% edges
for i = 1:d2_size(1)
    stream.addElement( [d2(i,1), d2(i,2)] , d2(i,3) );
end

% faces
for i = 1:d3_size(1)
    stream.addElement( [d3(i,1), d3(i,2), d3(i,3)] , d3(i,4) );
end

stream.finalizeStream();

%%% compute
persistence = api.Plex4.getModularSimplicialAlgorithm(3,2);
intervals = persistence.computeIntervals(stream);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%    O  P  T  I  O  N  A  L    %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This part is used to create the structure storeing all Persistence
% diagram

m_int = interval2Double(intervals);
switch length(filename)
    case {16,15,14,13}
        PD.(genvarname(filename([1:end-10 end-6:end-5, end-1:end]))) = m_int;
    case {11,10,9,8}
        PD.(genvarname(filename([1:end-5 end-1:end]))) = m_int;
end

%% plot

handle = plot_barcodes(intervals);
title([filename, ' Persistence Diagram']);

%% save picture

saveas(handle, [resultfolder, '/Figs/' filename, '-PD'], 'fig');
saveas(handle, [resultfolder, '/PNGs/', filename, '-PD'], 'png');