function [ d2 ] = constructCN_d2( d2, a1, a2 )
%constructCN_d2 updates the d2 sparse network (self-defined) by adding a
% one corresponding to another publication of authors a1 and a2.
% 
% d2 matrix has the structure such that the first two columns are the
% indexes of authors (first column always < second column), and the third
% column represents the total number of publications between them.
%
% If such an entry (a1, a2) has not been created before, create a new entry
% with third column = 1; if such an entry has been created, add one to the
% third column
% 
%  INPUT:  d2: the matrix (self defined structure) to be updated
%          a1: the index of the first author (not ordered)
%          a2: the index of the second author (not ordered)
% OUTPUT:  d2: the updated matrix



% if the order is incorrect
Authors = [a1 a2];
Authors = sort(Authors);
a1 = Authors(1);
a2 = Authors(2);

% initialize
d2_size = size(d2);

% begin case
if d2_size(1) == 0 % matrix is empty
    d2(1,:) = [a1, a2, 1];
else
    location = (d2(:,1) == a1) .* (d2(:,2) == a2);
    
    if sum(location) % find it
        d2(:,3) = d2(:,3) + eye(d2_size(1)) * location;
    else % not find it
        d2 = [d2; [a1, a2, 1]];
    end
end


end

