function [ d3 ] = constructCN_d3( d3, a1, a2, a3 )
%constructCN_d3 updates the d3 sparse network (self-defined) by adding a
% one corresponding to another publication of authors a1, a2, a3.
% 
% d3 matrix has the structure such that the first two columns are the
% indexes of authors (first column always < second column < third column),
% and the last column represents the total number of publications between
% them.
%
% If such an entry (a1, a2, a3) has not been created before, create a new entry
% with last column = 1; if such an entry has been created, add one to the
% last column
% 
%  INPUT:  d3: the matrix (self defined structure) to be updated
%          a1: the index of the first author (not ordered)
%          a2: the index of the second author (not ordered) 
%          a3: the index of the third author (not ordered) 
% OUTPUT:  d3: the updated matrix



% if the order is incorrect
Authors = [a1 a2, a3];
Authors = sort(Authors);
a1 = Authors(1);
a2 = Authors(2);
a3 = Authors(3);

% initialize
d3_size = size(d3);

% begin case
if d3_size(1) == 0 % matrix is empty
    d3(1,:) = [a1, a2, a3, 1];
else
    location = (d3(:,1) == a1) .* (d3(:,2) == a2) .* (d3(:,3) == a3);
    
    if sum(location) % find it
        d3(:,4) = d3(:,4) + eye(d3_size(1)) * location;
    else % not find it
        d3 = [d3; [a1, a2, a3, 1]];
    end
end


end

