function [ d2, d3] = constructCN_generateMatrix_123( output, matrix_size )
%constructCN_generateMatrix generates d2, d3, d4 self-defined matrix based
% on num_output (which is a matrix, each row represents a publication, each
% element in that row denotes the ID or ordinal of that author)
%
% DISTANCE DESCENDING WITH DEGREE:
% An update in higher dimensional matrix will update all lower dimensional
% matrix, i.e. a paper is written by (a,b,c,d), then d^4(a,b,c,d)++,
% d^3(a,b,c)++, ...., d^2(a,b)++....
%
% HIGHEST DIMENSION -- 4:
% If a paper is writen by more than 4 people, we just update all distance
% matrix of degree <= 4
%
% SELF DEFINED MATRIX STRUCTURE:
% d2 matrix has the structure such that the first two columns are the
% indexes of authors (first column always < second column), and the third
% column represents the total number of publications between them.
% 
% INPUT: output: num matrix generated by contructCN_txt2num.m
%   matrix_size: size of output


% initilize
d2 = []; d3 = [];

% loop
for i = 1:matrix_size(1)
%     
%     %%% DEBUGGING %%%%
%     disp(i);
%     if(sum(sum(d2 == 0)))
%         disp('Notice');
%     end
%     %%% END OF DEBUGGING %%%%
    
    switch sum(output(i,:) > 0) % num of authors in this paper
        case 2
            d2 = constructCN_d2( d2, output(i,1), output(i,2)) ;
            
        case 3
            d3 = constructCN_d3( d3, ...
                output(i,1), output(i,2), output(i,3) );
            
            d2 = constructCN_d2( d2, output(i,1), output(i,2) );
            d2 = constructCN_d2( d2, output(i,1), output(i,3) );
            d2 = constructCN_d2( d2, output(i,2), output(i,3) );
            
        case 4
            
            d3 = constructCN_d3(d3, output(i,1), output(i,2), output(i,3));
            d3 = constructCN_d3(d3, output(i,1), output(i,2), output(i,4));
            d3 = constructCN_d3(d3, output(i,1), output(i,3), output(i,4));
            d3 = constructCN_d3(d3, output(i,2), output(i,3), output(i,4));
            
            d2 = constructCN_d2( d2, output(i,1), output(i,2) );
            d2 = constructCN_d2( d2, output(i,1), output(i,3) );
            d2 = constructCN_d2( d2, output(i,1), output(i,4) );
            d2 = constructCN_d2( d2, output(i,2), output(i,3) );
            d2 = constructCN_d2( d2, output(i,2), output(i,4) );
            d2 = constructCN_d2( d2, output(i,3), output(i,4) );
            
        case 5
            
            Choices = nchoosek( output(i, 1:5), 3 );
            for j = 1:nchoosek(5,3)
                d3 = constructCN_d3( d3, ...
                    Choices(j,1), Choices(j,2), Choices(j,3) );
            end
            
            Choices = nchoosek( output(i, 1:5), 2 );
            for j = 1:nchoosek(5,2)
                d2 = constructCN_d2( d2, Choices(j,1), Choices(j,2) );
            end
            
            
        case 6
            
            Choices = nchoosek( output(i, 1:6), 3 );
            for j = 1:nchoosek(6,3)
                d3 = constructCN_d3( d3, ...
                    Choices(j,1), Choices(j,2), Choices(j,3) );
            end
            
            Choices = nchoosek( output(i, 1:6), 2 );
            for j = 1:nchoosek(6,2)
                d2 = constructCN_d2( d2, Choices(j,1), Choices(j,2) );
            end
            
            
        case 7
            
            Choices = nchoosek( output(i, 1:7), 3 );
            for j = 1:nchoosek(7,3)
                d3 = constructCN_d3( d3, ...
                    Choices(j,1), Choices(j,2), Choices(j,3) );
            end
            
            Choices = nchoosek( output(i, 1:7), 2 );
            for j = 1:nchoosek(7,2)
                d2 = constructCN_d2( d2, Choices(j,1), Choices(j,2) );
            end
            
            
        case 8
            
            Choices = nchoosek( output(i, 1:8), 3 );
            for j = 1:nchoosek(8,3)
                d3 = constructCN_d3( d3, ...
                    Choices(j,1), Choices(j,2), Choices(j,3) );
            end
            
            Choices = nchoosek( output(i, 1:8), 2 );
            for j = 1:nchoosek(8,2)
                d2 = constructCN_d2( d2, Choices(j,1), Choices(j,2) );
            end
    end
end



end

