function [ output, idx, num_of_authors, matrix_size, d1 ] = constructCN_txt2num( input_unchecked )
% constructCN_txt2num: based on the input txt matrix, generate a matrix of
% exact same dimension, with each entry replaced by the number representing
% this unique author, also output a matrix with each element corresponding
% to its representative author
%
% INPUT:    input: input matrix, authors, in txt
%
% OUTPUT:  output: output matrix, number representing the ID of different
% authors, i.e. same author will be allocated with same number; 0 means
% this cell in the matrix does not correspond to an author
%             idx: index matrix
%  num_of_authors: total number of different authors
%     matrix_size: size of input and output
%              d1: represents the number of publications for corresponding
%              authors in idx.



% check: for each row, if the first element is 'Author' or 'Anon', delete
% this row
input_unchecked_size = size(input_unchecked);

if strcmp(input_unchecked(1,1), 'Author')...
        || strcmp(input_unchecked(1,1), 'Anon') 
    input = input_unchecked(2:end, :);
    rows_deleted = 1;
else
    input = input_unchecked;
    rows_deleted = 0;
end
    
for i = 2: input_unchecked_size(1) - 1
    if (strcmp(input_unchecked(i,1), 'Author')...
            || strcmp(input_unchecked(i,1), 'Anon'))
        input = input( [1:i-rows_deleted-1, i-rows_deleted+1:end], :);
        rows_deleted = rows_deleted + 1;
    end
end

if strcmp(input_unchecked( input_unchecked_size(1),1 ), 'Author')...
        || strcmp( input_unchecked( input_unchecked_size(1),1 ), 'Anon')
    input = input(1:end-1, :);
end

% initilization
matrix_size = size(input);
matrix_size(2) = min(8, matrix_size(2)); % we don't consider d > 8

output = zeros(matrix_size);
idx = cell( matrix_size(1) * matrix_size(2), 1 );
d1 = zeros( matrix_size(1) * matrix_size(2), 1 );
num_of_authors = 0;

% remove ()
for i = 1:matrix_size(1)
    for j = 1:matrix_size(2)
        str = char(input(i,j));
        
        for k = 1:length(str)
            if str(k) == '(' % we find ()
                input(i,j) = {str(1:k-1)}; % remove
            end
        end
        
    end
end

% loop
for i = 1: matrix_size(1)
    for j = 1: matrix_size(2)
        
        if ~strcmp(input(i,j), '') % is an author rather than ''
            
            %%% author has appeared
            if sum(strcmp(idx, input(i,j))) 
                % 1. change corresponding output to the number
                output(i,j) = find(strcmp(idx, input(i,j)));
                d1(strcmp(idx, input(i,j))) =...
                    d1(strcmp(idx, input(i,j))) + 1;
                    
            %%% author has not appeared
            else
                % 1. increase num_of_authors (current audinal)
                num_of_authors = num_of_authors + 1;
                
                % 2. change corresponding output to the number
                output(i,j) = num_of_authors;
                
                % 3. copy author name to idx, corresponding d1++
                idx(num_of_authors) = input(i,j);
                d1(num_of_authors) = 1;
                
            end
        end    
        
    end
end

% remove unnecessary '' for idx and d1
idx = idx(1:num_of_authors);
d1 = d1(1:num_of_authors);

end

