function [homology ] = intervalIn1D2Double(intervalInOneDim)
% INTERVAL IN ONE DIMENSION TO DOUBLE convert string representing homology
% group in a certain dimension to Matlab matrix representing the birth and
% death of each persistence homology pair
%
%   INPUT: in format [[1.0, 2.0), [0.0, infinity)]
%  OUTPUT: matrix, Inf, -Inf representing infinite counterpart
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

delimiter = ')';    % For tabs, use: delimiter = sprintf('\t');

% Find the delimiters
delimIdx = find(intervalInOneDim == delimiter);

% Pretend there are delimiters at the beginning and end, for the loop below
delimIdx = [-1  delimIdx(1:end)];

% Preallocate cell array to hold substrings
homology = zeros(length(delimIdx) - 1, 2);

% Process each element
for i = 1:length(delimIdx) - 1

    % Find the text between the delimiters
    %(don't include the delimiters)
    startOffset = delimIdx(i)   + 4;
    endOffset   = delimIdx(i+1) - 1;

    % Get the element
    individual_homology = intervalInOneDim(startOffset:endOffset);
    
    % Find partition
    birth_death = ',';
    birth_death_Idx = find(individual_homology == birth_death);
    
    % Find birth death time, in string
    birth_str = individual_homology(1 : birth_death_Idx - 1);
    death_str = individual_homology(birth_death_Idx + 2 : end);
    
    % check infinity, to double
    if strcmp(birth_str, '-infinity')
        birth = -Inf;
    else
        birth = str2double(birth_str);
    end
    if strcmp(death_str, 'infinity')
        death = Inf;
    else
        death = str2double(death_str);
    end
        
    % update homology matrix
    homology(i,1) = birth;
    homology(i,2) = death;

end

end

